import 'package:flutter/material.dart';
import 'package:flutter_login_module/presentation/resources/LoginStyles.dart';
import 'package:flutter_login_module/presentation/resources/LoginColors.dart';


abstract class LoginWidgetFactory {
  
  static Widget buildEmptyVerticalSeparator({double height}) {
    return SizedBox(height: height);
  }

  static Widget buildEmptyHorizontalSeparator({double width}) {
    return SizedBox(width: width,);
  }

  static Widget buildSigninBtn(Widget icon, String text, Function() onClick, {Color color = LoginColors.buttonBorderColor}) {
    return FlatButton(
      onPressed: () {
        onClick.call();
      },
      color: Colors.transparent,
      shape: RoundedRectangleBorder(
        side: BorderSide(
          color: color, //Color of the border
          style: BorderStyle.solid,
          width: 1.0, //width of the border
        ),
        borderRadius: BorderRadius.circular(50.0),
      ),
      child: _buildButtonContent(icon, text),
    );
  }
  
  static _buildButtonContent(Widget icon, String text) => Padding(
    padding: EdgeInsets.all(12.0),
    child: Row(
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        icon,
        Expanded(
            child: Align(
                alignment: Alignment.center,
                child: Padding(
                    padding: EdgeInsets.symmetric(horizontal: 4.0),
                    child: Text(text, style: SessionStyles.buttonStyle)
                )
            )
        ),
      ],
    ),
  );
}